@@ -57,6 +57,7 @@ void loadTileProviders() {
 
 void loadConfig() {
     loadTileProviders();
+	initGeocodingProviders();
 
     GKeyFile *keyfile;
     GError *error = NULL;
@@ -68,6 +69,7 @@ void loadConfig() {
     if (g_key_file_load_from_file(keyfile, GLOBAL_CONFIG_FILE, 0, &error)) {
         options.referer = g_key_file_get_string(keyfile, "Network", "httpReferer", NULL);
         options.userAgent = g_key_file_get_string(keyfile, "Network", "httpUserAgent", NULL);
+        options.curlVerbose = g_key_file_get_integer(keyfile, "Network", "curlVerbose", NULL);
         canvas.zoom = g_key_file_get_integer(keyfile, GROUP_DEFAULTS, "zoom", NULL);
         canvas.tilex = g_key_file_get_integer(keyfile, GROUP_DEFAULTS, "tilex", NULL);
         canvas.tiley = g_key_file_get_integer(keyfile, GROUP_DEFAULTS, "tiley", NULL);
@@ -138,12 +140,16 @@ void loadConfig() {
 
     if (geocodingProvider != NULL) {
     	int i;
-    	for (i = 0; i < MAX_GEOCODING_PROVIDERS; i++) {
-    		if (g_str_equal(geocodingProviderNames[i], geocodingProvider)) {
-    			options.geocodingProvider = i;
+    	for (i = 0; i < geocodingProviders -> len; i++) {
+    		if (g_str_equal(g_array_index(geocodingProviders, GeocodingProvider, i).name, geocodingProvider)) {
+    			options.geocodingProvider = g_array_index(geocodingProviders, GeocodingProvider, i);
     		}
     	}
     }
+
+    if (options.geocodingProvider.name == NULL) {
+    	options.geocodingProvider = g_array_index(geocodingProviders, GeocodingProvider, 0);
+    }
 }
 
 void saveConfig() {
@@ -162,7 +168,7 @@ void saveConfig() {
     g_key_file_set_double(keyfile, "CurrentView", "x", canvas.x);
     g_key_file_set_double(keyfile, "CurrentView", "y", canvas.y);
     g_key_file_set_string(keyfile, "Options", "tileProvider", canvas.provider -> name);
-    g_key_file_set_string(keyfile, "Options", "geocodingProvider", geocodingProviderNames[options.geocodingProvider]);
+    g_key_file_set_string(keyfile, "Options", "geocodingProvider", options.geocodingProvider.name);
     gchar* data = g_key_file_to_data(keyfile, &lenght, &error);
     if (data == NULL || lenght <= 0) {
         fprintf(stderr, "Error dumping setting to data: %s\n", error->message);
