@@ -21,8 +21,7 @@
 #include "../main.h"
 #include "geocoder.h"
 
-#define CLOUDMADE_QUERY_URL "http://geocoding.cloudmade.com/e4b1777b4b5154d69dbfc4678216183a/geocoding/v2/find.js?query=%s&return_location=true"
-
+char* cloudmade_prepare_url(char* encodedQuery);
 void cloudmade_parse_response(char* response);
 
 #endif /* CLOUDMADE_GEOCODER_H_ */
