@@ -21,6 +21,8 @@
 #include "../network.h"
 #include "../tileengine.h"
 
+#include "coordinate_reader.h"
+
 typedef enum {
 	NO_QUERY, QUERY_IN_PROGRESS, DOWNLOAD_ERROR, PARSE_ERROR, ZERO_RESULTS, RESULTS_READY
 } SearchResultStatus;
@@ -28,6 +30,8 @@ typedef enum {
 extern volatile SearchResultStatus searchResultsStatus;
 extern GList* geocodingResults;
 
+void initGeocodingProviders();
+
 void processNewSearchQuery(char* query);
 
 void processGeocoding();
