@@ -25,7 +25,7 @@
 #endif
 #define M_PI 3.14159265358979323846
 
-#define CLOUDGPS_VERION "0.4.6"
+#define CLOUDGPS_VERION "0.4.7"
 
 /** Equatorial earth radius in meters. */
 #define EARTH_RADIUS 6378137
@@ -51,20 +51,20 @@ typedef enum {
     LANDSCAPE = 0, PORTRAIT = 1
 } Orientation;
 
-
-#define MAX_GEOCODING_PROVIDERS 2
-
-extern char* geocodingProviderNames[];
-
-typedef enum {
-	CLOUDMADE = 0, GOOGLE = 1
+typedef struct {
+	char* name;
+	char* (*prepareUrl)(char* encodedQuery);
+	void (*parseResponse)(char* response);
 } GeocodingProvider;
 
+extern GArray* geocodingProviders;
+
 struct {
     int mipmapToggle;
     int showGrid, showCoordinates, accelerometerEnabled;
     int showDebugTiles;
     int locallyLoadedFadeTime, downloadedFadeTime, zoomChangeFadeTime;
+    int curlVerbose;
 
     Orientation orientation;
     char *userAgent;
