@@ -847,10 +847,10 @@ void updateUi() {
 	} else {
 		canvas.arrowPos = 0;
 	}
-
-	toScreenCoordinate(&tc, &position ->x, &position -> y);
-	position -> x -= position -> texture.size / 2 / canvas.scale;
-	position -> y -= position -> texture.size / 2 / canvas.scale;
+	Point p;
+	toScreenCoordinate(&tc, &p);
+	position -> x = p.x - position -> texture.size / 2 / canvas.scale;
+	position -> y = p.y - position -> texture.size / 2 / canvas.scale;
 
 	position -> color.a = 0.75 + 0.25 * sin(nowMillis / 500.0);
 	position -> color.r = position -> color.a;
